@@ -1,40 +1,30 @@
-"""
-Class for interfacing with the Censys Seeds API.
-"""
-
+"""Interact with the Censys Seeds API."""
 from typing import Optional
 
-from censys.asm.api import CensysAsmAPI
+from .api import CensysAsmAPI
 
 
 class Seeds(CensysAsmAPI):
-    """
-    Seeds API class
-    """
+    """Seeds API class."""
 
-    def __init__(self, api_key: Optional[str] = None, **kwargs):
-        CensysAsmAPI.__init__(self, api_key, **kwargs)
-        self.base_path = "seeds"
+    base_path = "seeds"
 
     def get_seeds(self, seed_type: Optional[str] = None) -> dict:
-        """
-        Requests seed data.
+        """Requests seed data.
 
         Args:
-            seed_type (str, optional): Seed type
-                ['IP_ADDRESS', 'DOMAIN_NAME', 'CIDR', 'ASN'].
+            seed_type (str):
+                Optional; Seed type ['IP_ADDRESS', 'DOMAIN_NAME', 'CIDR', 'ASN'].
 
         Returns:
             dict: Seed search results.
         """
-
         args = {"type": seed_type}
 
         return self._get(self.base_path, args=args)["seeds"]
 
     def get_seed_by_id(self, seed_id: int) -> dict:
-        """
-        Requests seed data by ID.
+        """Requests seed data by ID.
 
         Args:
             seed_id (int): Seed ID to get.
@@ -42,14 +32,12 @@ class Seeds(CensysAsmAPI):
         Returns:
             dict: Seed search result.
         """
-
         path = f"{self.base_path}/{seed_id}"
 
         return self._get(path)
 
-    def add_seeds(self, seeds: list, force: Optional[bool] = False) -> dict:
-        """
-        Add seeds to the ASM platform.
+    def add_seeds(self, seeds: list, force: Optional[bool] = None) -> dict:
+        """Add seeds to the ASM platform.
 
         Args:
             seeds (list): List of seed objects to add.
@@ -58,52 +46,51 @@ class Seeds(CensysAsmAPI):
         Returns:
             dict: Added seeds results.
         """
-
         data = {"seeds": seeds}
         args = {"force": force}
 
         return self._post(self.base_path, args=args, data=data)
 
     def replace_seeds_by_label(
-        self, label: str, seeds: list, force: Optional[bool] = False
+        self, label: str, seeds: list, force: Optional[bool] = None
     ) -> dict:
-        """
-        Replace seeds in the ASM platform by label.
+        """Replace seeds in the ASM platform by label.
 
         Args:
             label (str): Label name to replace by.
             seeds (list): List of seed objects to add.
-            force (bool, optional): Forces replace operation.
+            force (bool): Optional; Forces replace operation.
 
         Returns:
             dict: Added and removed seeds results.
         """
-
         data = {"seeds": seeds}
         args = {"label": label, "force": force}
 
         return self._put(self.base_path, args=args, data=data)
 
     def delete_seeds_by_label(self, label: str) -> dict:
-        """
-        Delete seeds in the ASM platform by label.
+        """Delete seeds in the ASM platform by label.
 
         Args:
             label (str): Label name to delete by.
-        """
 
+        Returns:
+            dict: Delete results.
+        """
         args = {"label": label}
 
         return self._delete(self.base_path, args=args)
 
     def delete_seed_by_id(self, seed_id: int) -> dict:
-        """
-        Delete a seed in the ASM platform by id.
+        """Delete a seed in the ASM platform by id.
 
         Args:
             seed_id (int): Seed ID to delete by.
-        """
 
+        Returns:
+            dict: Delete results.
+        """
         path = f"{self.base_path}/{seed_id}"
 
         return self._delete(path)
